package data_manage

import (
	"fmt"
	"hongze/hongze_task/utils"
	"rdluck_tools/orm"
	"strconv"
	"strings"
	"time"
)

func AddEdbDataManualBySql(sqlStr string) (err error) {
	o := orm.NewOrm()
	o.Using("data")
	_, err = o.Raw(sqlStr).Exec()
	return
}

func GetEdbDataManualMaxOrMinDate(edbCode string) (min_date, max_date string, err error) {
	o := orm.NewOrm()
	o.Using("data")
	sql := ` SELECT MIN(data_time) AS min_date,MAX(data_time) AS max_date FROM edb_data_manual WHERE edb_code=? `
	err = o.Raw(sql, edbCode).QueryRow(&min_date, &max_date)
	return
}

type ManualEdbdata struct {
	TradeCode  string    `orm:"column(TRADE_CODE);pk" description:"指标编码"`
	Dt         string    `orm:"column(DT)" description:"日期"`
	Close      string    `orm:"column(CLOSE)" description:"值"`
	ModifyTime time.Time `orm:"column(modify_time)" description:"修改时间"`
}

func GetEdbdataManualByTradeCode(condition string, pars []interface{}) (item []*ManualEdbdata, err error) {
	sql := ` SELECT  * FROM edbdata WHERE 1=1 `
	o := orm.NewOrm()
	o.Using("edb")
	if condition != "" {
		sql += condition
	}
	sql+=` ORDER BY DT DESC `
	_, err = o.Raw(sql, pars).QueryRows(&item)
	return
}

func GetEdbDataManualByCodeAndDate(edbCode string, startDate string) (count int, err error) {
	o := orm.NewOrm()
	o.Using("data")
	sql := ` SELECT COUNT(1) AS count FROM edb_data_manual WHERE edb_code=? AND data_time=? `
	err = o.Raw(sql, edbCode, startDate).QueryRow(&count)
	return
}

func ModifyEdbDataManual(edbInfoId int64, dataTime, value string) (err error) {
	o := orm.NewOrm()
	o.Using("data")
	sql := ` UPDATE edb_data_manual SET value=?,modify_time=NOW() WHERE edb_info_id=? AND data_time=? `
	_, err = o.Raw(sql, value, edbInfoId, dataTime).Exec()
	return
}

//刷新手工指标数据
func RefreshManual(edbInfoId int, edbCode, startDate, endDate string) (err error) {
	o := orm.NewOrm()
	o.Using("data")
	o.Begin()
	defer func() {
		if err != nil {
			o.Rollback()
		} else {
			o.Commit()
		}
	}()

	if err != nil {
		return
	}
	edbInfoIdStr := strconv.Itoa(edbInfoId)
	//计算数据
	var condition string
	var pars []interface{}

	if edbCode != "" {
		condition += " AND TRADE_CODE=? "
		pars = append(pars, edbCode)
	}

	if startDate != "" {
		condition += " AND DT>=? "
		pars = append(pars, startDate)
	}

	if endDate != "" {
		condition += " AND DT<=? "
		pars = append(pars, endDate)
	}

	manualDataList, err := GetEdbdataManualByTradeCode(condition, pars)

	addSql := ` INSERT INTO edb_data_manual(edb_info_id,edb_code,data_time,value,create_time,modify_time,status,data_timestamp) values `
	var isAdd bool
	for _, v := range manualDataList {
		item := v
		count, err := GetEdbDataManualByCodeAndDate(v.TradeCode, v.Dt)
		if err != nil && err.Error() != utils.ErrNoRow() {
			return err
		}
		if count <= 0 {
			nowStr := time.Now().Format(utils.FormatDateTime)
			eDate := item.Dt
			sValue := item.Close
			dataTime, err := time.Parse(utils.FormatDate, eDate)
			if err != nil {
				return err
			}
			timestamp := dataTime.UnixNano() / 1e6
			timeStr := fmt.Sprintf("%d", timestamp)
			addSql += "("
			addSql += edbInfoIdStr + "," + "'" + edbCode + "'" + "," + "'" + eDate + "'" + "," + sValue + "," + "'" + nowStr + "'" +
				"," + "'" + nowStr + "'" + "," + "1" + "," + "'" + timeStr + "'"
			addSql += "),"
			isAdd = true
		} else {
			err = ModifyEdbDataManual(int64(edbInfoId), v.Dt, v.Close)
			if err != nil {
				return err
			}
		}
	}
	if isAdd {
		addSql = strings.TrimRight(addSql, ",")
		_, err = o.Raw(addSql).Exec()
		if err != nil {
			return err
		}
	}

	maxAndMinItem, err := GetEdbInfoMaxAndMinInfo(utils.DATA_SOURCE_MANUAL, edbCode)
	if err != nil {
		return err
	}
	if maxAndMinItem != nil {
		err = ModifyEdbInfoMaxAndMinInfo(edbInfoId, maxAndMinItem)
		if err != nil {
			return err
		}
	}
	return
}
